@@ -17,7 +17,7 @@
 %                                 July 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright @ 2003 ImageMagick Studio LLC, a non-profit organization         %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -69,6 +69,13 @@
 #if (defined(MAGICKCORE_HAVE_NEWLOCALE) || defined(MAGICKCORE_WINDOWS_SUPPORT)) && !defined(__MINGW32__)
 #  define MAGICKCORE_LOCALE_SUPPORT
 #endif
+
+#if defined(MAGICKCORE_WINDOWS_SUPPORT)
+#  if !defined(locale_t)
+#    define locale_t _locale_t
+#  endif
+#endif
+
 #define LocaleFilename  "locale.xml"
 
 /*
@@ -254,7 +261,11 @@ static SplayTreeInfo *AcquireLocaleSplayTree(const char *filename,
 static void DestroyCLocale(void)
 {
   if (c_locale != (locale_t) NULL)
+#if defined(MAGICKCORE_WINDOWS_SUPPORT)
+    _free_locale(c_locale);
+#else
     freelocale(c_locale);
+#endif
   c_locale=(locale_t) NULL;
 }
 #endif
@@ -339,7 +350,7 @@ MagickPrivate ssize_t FormatLocaleFileList(FILE *file,
       n=(ssize_t) vfprintf(file,format,operands);
     else
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
-      n=(ssize_t) vfprintf_l(file,format,locale,operands);
+      n=(ssize_t) _vfprintf_l(file,format,locale,operands);
 #else
       n=(ssize_t) vfprintf_l(file,locale,format,operands);
 #endif
@@ -430,7 +441,14 @@ MagickPrivate ssize_t FormatLocaleStringList(char *magick_restrict string,
       n=(ssize_t) vsnprintf(string,length,format,operands);
     else
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
-      n=(ssize_t) vsnprintf_l(string,length,format,locale,operands);
+#if _MSC_VER
+  #pragma warning(push)
+  #pragma warning(disable:4996)
+#endif
+      n=(ssize_t) _vsnprintf_l(string,length,format,locale,operands);
+#if _MSC_VER
+  #pragma warning(pop)
+#endif
 #else
       n=(ssize_t) vsnprintf_l(string,length,locale,format,operands);
 #endif
@@ -992,7 +1010,11 @@ MagickExport double InterpretLocaleValue(const char *magick_restrict string,
       if (locale == (locale_t) NULL)
         value=strtod(string,&q);
       else
+#if defined(MAGICKCORE_WINDOWS_SUPPORT)
+        value=_strtod_l(string,&q,locale);
+#else
         value=strtod_l(string,&q,locale);
+#endif
 #else
       value=strtod(string,&q);
 #endif
@@ -1128,15 +1150,19 @@ static void ChopLocaleComponents(char *path,const size_t components)
     *path='\0';
 }
 
+
+static void LocaleFatalErrorHandler(const ExceptionType severity,
+  const char *reason,const char *description) magick_attribute((__noreturn__));
+
 static void LocaleFatalErrorHandler(
   const ExceptionType magick_unused(severity),
   const char *reason,const char *description)
 {
   magick_unreferenced(severity);
 
-  if (reason == (char *) NULL)
-    return;
-  (void) FormatLocaleFile(stderr,"%s: %s",GetClientName(),reason);
+  (void) FormatLocaleFile(stderr,"%s: ",GetClientName());
+  if (reason != (char *) NULL)
+    (void) FormatLocaleFile(stderr," %s",reason);
   if (description != (char *) NULL)
     (void) FormatLocaleFile(stderr," (%s)",description);
   (void) FormatLocaleFile(stderr,".\n");
@@ -1262,8 +1288,8 @@ static MagickBooleanType LoadLocaleCache(SplayTreeInfo *cache,const char *xml,
                   file_xml=FileToXML(path,~0UL);
                   if (file_xml != (char *) NULL)
                     {
-                      status&=LoadLocaleCache(cache,file_xml,path,locale,
-                        depth+1,exception);
+                      status&=(MagickStatusType) LoadLocaleCache(cache,file_xml,
+                        path,locale,depth+1,exception);
                       file_xml=DestroyString(file_xml);
                     }
                 }
