@@ -606,9 +606,9 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
             GetMontageGeometry(montage_info->tile,number_images,&x_offset,&y,
               &sans,&sans);
           height=concatenate != MagickFalse ? max_height : extract_info.height;
-          y_offset+=((ssize_t) height+(extract_info.y+(ssize_t) border_width)*2+
-            (metrics.ascent-metrics.descent+4)*(ssize_t) number_lines+
-            (montage_info->shadow != MagickFalse ? 4 : 0));
+          y_offset+=(ssize_t) ((ssize_t) height+(extract_info.y+
+            (ssize_t) border_width)*2+(metrics.ascent-metrics.descent+4)*
+            (ssize_t) number_lines+(montage_info->shadow != MagickFalse ? 4 : 0));
           if (y_offset > (ssize_t) bounds.height)
             bounds.height=(size_t) y_offset;
           max_height=0;
@@ -664,7 +664,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     tile=0;
     while (tile < MagickMin((ssize_t) tiles_per_page,(ssize_t) number_images))
     {
-      if (strchr(image_list[tile]->filename,'\xff') == (char *) NULL)
+      if (strchr(image_list[tile]->filename,(int) '\xff') == (char *) NULL)
         (void) ConcatenateMagickString(montage->directory,
           image_list[tile]->filename,extent);
       else
@@ -840,9 +840,10 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
                 (metrics.ascent-metrics.descent+4)*MultilineCensus(value),
                 (double) (x_offset+(ssize_t) border_width),(double)
                 ((montage_info->frame ? y_offset+(ssize_t) height+(ssize_t)
-                border_width+4 : y_offset+(ssize_t) extract_info.height+
-                (ssize_t) border_width+
-                (montage_info->shadow != MagickFalse ? 4 : 0))+bevel_width));
+                border_width+4 : y_offset+(ssize_t)
+                (concatenate != MagickFalse ? max_height : extract_info.height)+
+                (ssize_t) border_width+(montage_info->shadow != MagickFalse ?
+                4 : 0))+bevel_width));
               (void) CloneString(&draw_info->geometry,tile_geometry);
               (void) CloneString(&draw_info->text,value);
               (void) AnnotateImage(montage,draw_info,exception);
@@ -853,9 +854,9 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
           (((tile+1) % (ssize_t) tiles_per_row) == 0))
         {
           x_offset=extract_info.x;
-          y_offset+=((ssize_t) height+(extract_info.y+(ssize_t) border_width)*2+
-            (metrics.ascent-metrics.descent+4)*number_lines+
-            (montage_info->shadow != MagickFalse ? 4 : 0));
+          y_offset+=(ssize_t) ((ssize_t) height+(extract_info.y+
+            (ssize_t) border_width)*2+(metrics.ascent-metrics.descent+4)*
+            number_lines+(montage_info->shadow != MagickFalse ? 4 : 0));
           max_height=0;
         }
       if (images->progress_monitor != (MagickProgressMonitor) NULL)
