@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -35,7 +35,7 @@
 %
 %
 %   20071202 TS * rewrote RLE decoder - old version could cause buffer overflows
-%               * failure of RLE decoding now thows error RLEDecoderError
+%               * failure of RLE decoding now throws error RLEDecoderError
 %               * fixed bug in RLE decoding - now all rows are decoded, not just
 %     the first one
 %   * fixed bug in reader - record offsets now handled correctly
@@ -88,10 +88,12 @@ typedef struct _PDBInfo
     attributes,
     version;
 
-  size_t
+  ssize_t
     create_time,
     modify_time,
-    archive_time,
+    archive_time;
+
+  size_t
     modify_number,
     application_info,
     sort_info;
@@ -317,11 +319,11 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickCoreSignature);
-  if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   image=AcquireImage(image_info,exception);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
@@ -387,7 +389,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   count=ReadBlob(image,sizeof(pdb_image.name),(unsigned char *) pdb_image.name);
   if (count != sizeof(pdb_image.name))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  pdb_image.version=ReadBlobByte(image);
+  pdb_image.version=(char) ReadBlobByte(image);
   pdb_image.type=(unsigned char) (ReadBlobByte(image));
   pdb_image.reserved_1=ReadBlobMSBLong(image);
   pdb_image.note=ReadBlobMSBLong(image);
@@ -476,7 +478,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           index=(Quantum) (*p & (0x80 >> bit) ? 0x00 : 0x01);
           SetPixelIndex(image,index,q);
-          q+=GetPixelChannels(image);
+          q+=(ptrdiff_t) GetPixelChannels(image);
           bit++;
           if (bit == 8)
             {
@@ -511,10 +513,10 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         for (x=0; x < (ssize_t) image->columns; x++)
         {
           shift-=2;
-          index=ConstrainColormapIndex(image,3UL-((*p >> shift) & 0x03),
+          index=(Quantum) ConstrainColormapIndex(image,3UL-((*p >> shift) & 0x03),
             exception);
           SetPixelIndex(image,index,q);
-          q+=GetPixelChannels(image);
+          q+=(ptrdiff_t) GetPixelChannels(image);
           if (shift == 0)
             {
               shift=8;
@@ -548,10 +550,10 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         for (x=0; x < (ssize_t) image->columns; x++)
         {
           shift-=4;
-          index=ConstrainColormapIndex(image,15UL-((*p >> shift) & 0x0f),
+          index=(Quantum) ConstrainColormapIndex(image,15UL-((*p >> shift) & 0x0f),
             exception);
           SetPixelIndex(image,index,q);
-          q+=GetPixelChannels(image);
+          q+=(ptrdiff_t) GetPixelChannels(image);
           if (shift == 0)
             {
               shift=8;
@@ -619,7 +621,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
             r=comment+strlen(comment);
           }
-        *r=c;
+        *r=(char) c;
         c=ReadBlobByte(image);
       }
       *r='\0';
@@ -628,7 +630,10 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) SetImageProperty(image,"comment",comment,exception);
       comment=DestroyString(comment);
     }
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  if (status == MagickFalse)
+    return(DestroyImageList(image));
   return(GetFirstImageInList(image));
 }
 
@@ -790,10 +795,10 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image,
   assert(image_info->signature == MagickCoreSignature);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,exception);
   if (status == MagickFalse)
     return(status);
@@ -814,7 +819,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image,
   (void) CopyMagickString(pdb_info.name,filename,sizeof(pdb_info.name));
   pdb_info.attributes=0;
   pdb_info.version=0;
-  pdb_info.create_time=GetMagickTime();
+  pdb_info.create_time=(ssize_t) GetMagickTime();
   pdb_info.modify_time=pdb_info.create_time;
   pdb_info.archive_time=0;
   pdb_info.modify_number=0;
@@ -913,8 +918,8 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image,
     for (x=0; x < (ssize_t) pdb_image.width; x++)
     {
       if (x < (ssize_t) image->columns)
-        buffer[literal+repeat]|=(0xff-scanline[x*packet_size]) >>
-          (8-bits_per_pixel) << bits*bits_per_pixel;
+        buffer[literal+repeat]|=(0xff-scanline[x*(ssize_t) packet_size]) >>
+          (8-bits_per_pixel) << bits*(ssize_t) bits_per_pixel;
       bits--;
       if (bits < 0)
         {
@@ -1007,6 +1012,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image,
   runlength=(unsigned char *) RelinquishMagickMemory(runlength);
   if (comment != (const char *) NULL)
     (void) WriteBlobString(image,comment);
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
